Crate zk_os_merkle_tree

Crate zk_os_merkle_tree 

Persistent ZK OS Merkle tree.

Structs

BatchOutput
Output of updating / inserting data in a MerkleTree.
BatchTreeProof
Merkle proof of batch insertion into MerkleTree.
Blake2Hasher
DefaultTreeParams
Default Merkle tree parameters that should balance its performance and I/O requirements.
DeserializeError
Error that can occur during deserialization.
MerkleTree
MerkleTreeReader
PatchSet
Immutable in-memory changeset that can atomically applied to a Database.
Patched
RocksDBWrapper
Main Database implementation wrapping a RocksDB reference.
TreeEntry
Entry in a Merkle tree associated with a key. Provided as an input for MerkleTree operations.

Enums

MerkleTreeColumnFamily
RocksDB column families used by the tree.
TreeOperation
Operation on a Merkle tree entry used in BatchTreeProof.

Traits

Database
Generic database functionality. Its main implementation is [RocksDB].
HashTree
Tree hashing functionality.
TreeParams
Marker trait for tree parameters.